use strict;
use warnings;

# this test was generated with Dist::Zilla::Plugin::Test::EOL 0.18

use Test::More 0.88;
use Test::EOL;

my @files = (
    'lib/Business/CyberSource.pm',
    'lib/Business/CyberSource/Client.pm',
    'lib/Business/CyberSource/Exception.pm',
    'lib/Business/CyberSource/Exception/AttributeIsRequiredNotToBeSet.pm',
    'lib/Business/CyberSource/Exception/ItemsOrTotal.pm',
    'lib/Business/CyberSource/Exception/NotACreditCard.pm',
    'lib/Business/CyberSource/Exception/Response.pm',
    'lib/Business/CyberSource/Exception/SOAPFault.pm',
    'lib/Business/CyberSource/Exception/UnableToDetectCardTypeCode.pm',
    'lib/Business/CyberSource/Factory/Request.pm',
    'lib/Business/CyberSource/Factory/Response.pm',
    'lib/Business/CyberSource/Factory/Rule.pm',
    'lib/Business/CyberSource/Message.pm',
    'lib/Business/CyberSource/MessagePart.pm',
    'lib/Business/CyberSource/Request.pm',
    'lib/Business/CyberSource/Request/AuthReversal.pm',
    'lib/Business/CyberSource/Request/Authorization.pm',
    'lib/Business/CyberSource/Request/Capture.pm',
    'lib/Business/CyberSource/Request/Credit.pm',
    'lib/Business/CyberSource/Request/DCC.pm',
    'lib/Business/CyberSource/Request/FollowOnCredit.pm',
    'lib/Business/CyberSource/Request/Role/BillingInfo.pm',
    'lib/Business/CyberSource/Request/Role/CreditCardInfo.pm',
    'lib/Business/CyberSource/Request/Role/DCC.pm',
    'lib/Business/CyberSource/Request/Role/TaxService.pm',
    'lib/Business/CyberSource/Request/Sale.pm',
    'lib/Business/CyberSource/Request/StandAloneCredit.pm',
    'lib/Business/CyberSource/RequestPart/BillTo.pm',
    'lib/Business/CyberSource/RequestPart/BusinessRules.pm',
    'lib/Business/CyberSource/RequestPart/Card.pm',
    'lib/Business/CyberSource/RequestPart/Item.pm',
    'lib/Business/CyberSource/RequestPart/PurchaseTotals.pm',
    'lib/Business/CyberSource/RequestPart/Service.pm',
    'lib/Business/CyberSource/RequestPart/Service/Auth.pm',
    'lib/Business/CyberSource/RequestPart/Service/AuthReversal.pm',
    'lib/Business/CyberSource/RequestPart/Service/Capture.pm',
    'lib/Business/CyberSource/RequestPart/Service/Credit.pm',
    'lib/Business/CyberSource/RequestPart/Service/Tax.pm',
    'lib/Business/CyberSource/Response.pm',
    'lib/Business/CyberSource/Response/Role/Amount.pm',
    'lib/Business/CyberSource/Response/Role/AuthCode.pm',
    'lib/Business/CyberSource/Response/Role/Base.pm',
    'lib/Business/CyberSource/Response/Role/DCC.pm',
    'lib/Business/CyberSource/Response/Role/ElectronicVerification.pm',
    'lib/Business/CyberSource/Response/Role/ProcessorResponse.pm',
    'lib/Business/CyberSource/Response/Role/ReasonCode.pm',
    'lib/Business/CyberSource/Response/Role/ReconciliationID.pm',
    'lib/Business/CyberSource/Response/Role/RequestDateTime.pm',
    'lib/Business/CyberSource/ResponsePart/AuthReply.pm',
    'lib/Business/CyberSource/ResponsePart/DCCReply.pm',
    'lib/Business/CyberSource/ResponsePart/PurchaseTotals.pm',
    'lib/Business/CyberSource/ResponsePart/Reply.pm',
    'lib/Business/CyberSource/ResponsePart/TaxReply.pm',
    'lib/Business/CyberSource/ResponsePart/TaxReply/Item.pm',
    'lib/Business/CyberSource/Role/Currency.pm',
    'lib/Business/CyberSource/Role/ForeignCurrency.pm',
    'lib/Business/CyberSource/Role/MerchantReferenceCode.pm',
    'lib/Business/CyberSource/Role/Traceable.pm',
    'lib/Business/CyberSource/Rule.pm',
    'lib/Business/CyberSource/Rule/ExpiredCard.pm',
    'lib/Business/CyberSource/Rule/RequestIDisZero.pm',
    'lib/MooseX/Types/CyberSource.pm',
    't/00-compile.t',
    't/00-report-prereqs.dd',
    't/00-report-prereqs.t',
    't/auth-reversal.t',
    't/authorization.t',
    't/billto-exceptions.t',
    't/billto.t',
    't/business-rules.t',
    't/capture.t',
    't/card.t',
    't/client.t',
    't/credit.t',
    't/dcc-autorization.t',
    't/dcc.t',
    't/error-exception.t',
    't/exceptions.t',
    't/factory-request.t',
    't/item-serialization.t',
    't/items.t',
    't/lib/Test/Business/CyberSource.pm',
    't/purchase-totals.t',
    't/response-removed-methods-successfully.t',
    't/response-sale.t',
    't/response.t',
    't/rule-expired-card.t',
    't/rule-request-id-is-zero.t',
    't/service.t'
);

eol_unix_ok($_, { trailing_whitespace => 1 }) foreach @files;
done_testing;
